from orm_choices import choices as choices_without_unknown
from orm_choices import choices_with_unknown as choices

from ak_vendor.constants import (
    RISK_ENUM_CRITICAL,
    RISK_ENUM_HIGH,
    RISK_ENUM_LOW,
    RISK_ENUM_MEDIUM,
    RISK_ENUM_PASSED,
)


@choices
class ProductEnum:
    class Meta:
        APPKNOX = [0, "Appknox"]
        DEVKNOX = [1, "Devknox"]


@choices
class AppactionEnum:
    class Meta:
        NO_PREFERENCE = [0, "NO_PREFERENCE"]
        HALT = [1, "HALT"]
        PROCEED = [2, "PROCEED"]


@choices
class OrganizationRolesEnum:
    class Meta:
        MEMBER = [0, "MEMBER"]
        OWNER = [1, "OWNER"]
        ADMIN = [2, "ADMIN"]


@choices_without_unknown
class OWASPEnum:
    """
    OWASP Enum
    """

    class Meta:
        A1_2013 = ["A1_2013", "A1_2013"]
        A2_2013 = ["A2_2013", "A2_2013"]
        A3_2013 = ["A3_2013", "A3_2013"]
        A4_2013 = ["A4_2013", "A4_2013"]
        A5_2013 = ["A5_2013", "A5_2013"]
        A6_2013 = ["A6_2013", "A6_2013"]
        A7_2013 = ["A7_2013", "A7_2013"]
        A8_2013 = ["A8_2013", "A8_2013"]
        A9_2013 = ["A9_2013", "A9_2013"]
        A10_2013 = ["A10_2013", "A10_2013"]

        M1_2016 = ["M1_2016", "M1_2016"]
        M2_2016 = ["M2_2016", "M2_2016"]
        M3_2016 = ["M3_2016", "M3_2016"]
        M4_2016 = ["M4_2016", "M4_2016"]
        M5_2016 = ["M5_2016", "M5_2016"]
        M6_2016 = ["M6_2016", "M6_2016"]
        M7_2016 = ["M7_2016", "M7_2016"]
        M8_2016 = ["M8_2016", "M8_2016"]
        M9_2016 = ["M9_2016", "M9_2016"]
        M10_2016 = ["M10_2016", "M10_2016"]


@choices
class PlatformEnum:
    """
    Platform Type Enum
    """

    class Meta:
        ANDROID = [0, "Android"]
        IOS = [1, "iOS"]
        WINDOWS = [2, "Windows"]
        COMMON = [3, "common (meta)"]


@choices
class DeviceTypeEnum:
    """
    Device type enum
    """

    class Meta:
        NO_PREFERENCE = [0, "No Preference"]
        PHONE_REQUIRED = [1, "Phone Required"]
        TABLET_REQUIRED = [2, "Tablet Required"]


@choices_without_unknown
class DynamicStatusEnum:
    """
    The Dynamic scanning status
    """

    class Meta:
        ERROR = [-1, "Error"]
        NONE = [0, "None"]
        INQUEUE = [1, "In Queue"]
        BOOTING = [2, "Booting"]
        DOWNLOADING = [3, "Downloading Package"]
        INSTALLING = [4, "Installing Package"]
        LAUNCHING = [5, "Launching App"]
        HOOKING = [6, "Hooking"]
        READY = [7, "Ready"]
        SHUTTING_DOWN = [8, "Shutting Down"]
        COMPLETED = [9, "Completed"]


@choices
class RiskEnum:
    """
    The risk level that is associated with an analysis
    """

    class Meta:
        PASSED = [RISK_ENUM_PASSED, "Passed"]
        LOW = [RISK_ENUM_LOW, "Low"]
        MEDIUM = [RISK_ENUM_MEDIUM, "Medium"]
        HIGH = [RISK_ENUM_HIGH, "High"]
        CRITICAL = [RISK_ENUM_CRITICAL, "Critical"]


@choices
class AnalysisEnum:
    """
    The status of the analysis
    """

    class Meta:
        ERROR = [0, "Error"]
        WAITING = [1, "Waiting"]
        RUNNING = [2, "Running"]
        COMPLETED = [3, "Completed"]


@choices
class ManualEnum:
    """
    Manual Assessment request state
    """

    class Meta:
        NONE = [0, "None"]
        REQUESTED = [1, "Requested"]
        ASSESSING = [2, "Assessing"]
        DONE = [3, "Done"]


@choices
class NotifyEnum:
    class Meta:
        INFO = [0, "Info"]
        SUCCESS = [2, "Success"]
        WARNING = [3, "Warning"]
        ALERT = [4, "Alert"]
        ERROR = [5, "Error"]


@choices
class SubmissionStatusEnum:
    class Meta:
        # Statuses if app is uploading using store URL
        STORE_NOT_STARTED = [10100, "Not Started"]
        STORE_VALIDATING_URL = [10101, "Validating URL"]
        STORE_URL_VALIDATION_FAILED = [10102, "Failed to Validate the URL"]
        STORE_DOWNLOAD_PREPARE = [10103, "Preparing to download from store"]
        STORE_DOWNLOADING = [10104, "Downloading from store"]
        STORE_DOWNLOAD_FAILED = [10105, "Failed to download from store"]
        STORE_UPLOAD_PREPARE = [10106, "Preparing to upload"]
        STORE_UPLOADING = [10107, "Uploading"]
        STORE_UPLOAD_FAILED = [10108, "Failed to upload"]

        # Statuses if app is uploaded using system file
        DOWNLOAD_PREPARE = [0, "Preparing to download the URL"]
        DOWNLOADING = [1, "Downloading the URL"]
        DOWNLOAD_FAILED = [2, "Failed to download the URL"]

        # Commom statuses for both URL and system file upload
        VALIDATE_PREPARE = [3, "Preparing to validate the file"]
        VALIDATING = [4, "Validating the file"]
        VALIDATE_FAILED = [5, "Failed to validate the file"]
        ANALYZE_PREPARE = [6, "Preparing to analyze the file"]
        ANALYZING = [7, "The file is being analyzed"]


@choices
class SubmissionSourceEnum:
    """
    Submission Source Enum
    """

    class Meta:
        UPLOAD = [0, "Upload"]  # to be deprecated
        STORE = [1, "Store"]
        SCM = [2, "Source Code Management"]  # unused
        DEVKNOX = [3, "Devknox"]  # unused
        DASHBOARD = [4, "Dashboard"]
        SDK = [5, "SDK"]
        API = [6, "API"]


@choices
class CollaborationRoleEnum:
    """
    User project role
    """

    class Meta:
        ADMIN = [0, "Admin"]
        MANAGER = [1, "Manager"]
        READ_ONLY = [2, "Read Only"]


@choices
class ContactSourceEnum:
    """
    Enum to identify the contact source
    """

    class Meta:
        HOME_PAGE = [0, "Home Page"]
        CONTACT_US = [1, "Contact Us"]


@choices
class ContactStatusEnum:
    """
    Enum to recognize the status  of the contact
    """

    class Meta:
        DEAD = [0, "Dead"]
        LIVE = [1, "Live"]


@choices
class ContactValidityEnum:
    """
    Enum to differentiate between contacts
    with valid info and invalid info.
    """

    class Meta:
        URL_INVALID = [0, "URL Invalid"]
        EMAIL_INVALID = [1, "Email Invalid"]
        NEW_NAME_SPACE = [2, "New Namespace"]
        ALL_VALID = [3, "All Valid"]


@choices
class PaymentSourceEnum:
    """
    Where did the payment take place?
    """

    class Meta:
        PAYPAL = [1, "Paypal"]
        STRIPE_MANUAL = [2, "Stripe Manual"]
        BANK_TRANSFER = [3, "Bank Transfer"]
        MANUAL = [4, "Manual"]
        STRIPE_RECURRING = [5, "Stripe Recurring"]


@choices
class PaymentDurationEnum:
    """
    Duration - Yearly/Monthly
    NOTE:
        This is a special-case of enum. Each enum represents no.of months
        rather than sequential number. This way, the codebase will be much
        smaller and cleaner.

        I know I asked no one should change ENUMS after deployment.
        But I am doing this only because I know for a fact that no one has
        used Yearly. Just verified

        -dhilipsiva
    """

    class Meta:
        MONTHLY = [1, "Monthly"]  # 1 Month
        QUARTERLY = [3, "Quaterly"]  # 3 Months
        HALFYEARLY = [6, "Halfyearly"]  # 6 months
        YEARLY = [10, "Yearly"]  # 10 months + 2 free months

    @staticmethod
    def days_for_duration(duration):
        """
        Number of days for given duration
        """
        months = duration
        DAYS = 31
        if duration == PaymentDurationEnum.YEARLY:
            months = 12
        # 31 days because Appknox is gracious
        return months * DAYS


@choices
class VulnerabilityTypeEnum:
    """
    Vulnerability Type
    """

    class Meta:
        STATIC = [1, "Static"]
        DYNAMIC = [2, "Dynamic"]
        MANUAL = [3, "Manual"]
        API = [4, "API"]


@choices
class ConfidenceEnum:
    """
    Confidence about the occurrence of a vulnerability
    """

    class Meta:
        LOW = [1, "Low"]
        MEDIUM = [2, "Medium"]
        HIGH = [3, "High"]


@choices
class UserTypeEnum:
    """
    Use Types
    """

    class Meta:
        APPKNOX = [1, "Appknox"]
        DEVKNOX = [2, "Devknox"]


@choices
class UserRoleEnum:
    """
    Role of User at Appknox
    """

    class Meta:
        CO_FOUNDER = [1, "Co-Founder"]
        EMPLOYEE = [2, "Employee"]
        PARTNER = [3, "Partner"]
        REGULAR = [4, "Regular"]


@choices
class UserDepartmentEnum:
    """
    The Department that the user belongs to
    """

    class Meta:
        TECHNOLOGY = [1, "Technology"]
        SECURITY = [2, "Security"]
        SALES = [3, "Sales"]
        MARKETING = [4, "Marketing"]
        DESIGN = [5, "Design"]


@choices
class AttackVectorEnum:
    """
    CVSSv3 attack vector
    """

    class Meta:
        NETWORK = ["N", "Network"]
        ADJACENT = ["A", "Adjacent"]
        LOCAL = ["L", "Local"]
        PHYSICAL = ["P", "Physical"]


@choices
class AttackComplexityEnum:
    """
    CVSSv3 attack complexity
    """

    class Meta:
        LOW = ["L", "Low"]
        HIGH = ["H", "High"]


@choices
class PrivilegesRequiredEnum:
    """
    CVSSv3 privileges required
    """

    class Meta:
        NONE = ["N", "None"]
        LOW = ["L", "Low"]
        HIGH = ["H", "High"]


@choices
class UserInteractionEnum:
    """
    CVSSv3 user interaction
    """

    class Meta:
        NOT_REQUIRED = ["N", "Not Required"]
        REQUIRED = ["R", "Required"]


@choices
class ScopeEnum:
    """
    CVSSv3 scope
    """

    class Meta:
        UNCHANGED = ["U", "Unchanged"]
        CHANGED = ["C", "Changed"]


@choices
class ConfidentialityImpactEnum:
    """
    CVSSv3 confidentiality impact
    """

    class Meta:
        HIGH = ["H", "High"]
        LOW = ["L", "Low"]
        NONE = ["N", "None"]


@choices
class IntegrityImpactEnum:
    """
    CVSSv3 integrity impact
    """

    class Meta:
        HIGH = ["H", "High"]
        LOW = ["L", "Low"]
        NONE = ["N", "None"]


@choices
class AvailabilityImpactEnum:
    """
    CVSSv3 availability impact
    """

    class Meta:
        HIGH = ["H", "High"]
        LOW = ["L", "Low"]
        NONE = ["N", "None"]


@choices
class MFAMethodEnum:
    """
    Multi-factor authentication method
    """

    class Meta:
        NONE = [0, "None"]
        TOTP = [1, "TOTP"]
        HOTP = [2, "HOTP"]


@choices
class FileFormatEnum:
    """
    The file types.
    """

    class Meta:
        ANDROID_APK = [0, "APK"]
        ANDROID_AAB = [1, "AAB"]
        IOS_IPA = [2, "IPA"]



# (c) 2017, XYSec Labs
#
# This list based on the AdAway blocklist (https://github.com/AdAway/AdAway)
#
# AdAway default blocklist
# Blocking mobile ad providers and some analytics providers
#
# Contribute:
# Create an issue at https://github.com/AdAway/AdAway/issues
#
# Changelog:
# 2016-07-18 Now hosted on GitHub + Cloudflare
# 2014-05-18 Now with a valid SSL certificate available at
#            https://adaway.org/hosts.txt
# 2013-03-29 Integrated some hosts from
#            http://adblock.gjtech.net/?format=hostfile
# 2013-03-14 Back from the dead
#
# License:
# CC Attribution 3.0 (http://creativecommons.org/licenses/by/3.0/)
#
# Contributions by:
# Kicelo, Dominik Schuermann
#

blocklist = [
    "lb.usemaxserver.de",
    "tracking.klickthru.com",
    "gsmtop.net",
    "click.buzzcity.net",
    "ads.admoda.com",
    "stats.pflexads.com",
    "a.glcdn.co",
    "wwww.adleads.com",
    "ad.madvertise.de",
    "apps.buzzcity.net",
    "ads.mobgold.com",
    "android.bcfads.com",
    "show.buzzcity.net",
    "api.analytics.omgpop.com",
    "r.edge.inmobicdn.net",
    "www.mmnetwork.mobi",
    "img.ads.huntmad.com",
    "creative1cdn.mobfox.com",
    "admicro2.vcmedia.vn",
    "admicro1.vcmedia.vn",
    "s3.phluant.com",
    "c.vrvm.com",
    "go.vrvm.com",
    "static.estebull.com",
    "mobile.Banzai.it",
    "ads.xxxad.net",
    "img.ads.mojiva.com",
    "adcontent.saymedia.com",
    "ads.saymedia.com",
    "ftpcontent.worldnow.com",
    "s0.2mdn.net",
    "img.ads.mocean.mobi",
    "bigmobileads.com",
    "banners.bigmobileads.com",
    "ads.mopub.com",
    "images.mpression.net",
    "images.millennialmedia.com",
    "oasc04012.247realmedia.com",
    "assets.cntdy.mobi",
    "ad.leadboltapps.net",
    "api.airpush.com",
    "ad.where.com",
    "i.tapit.com",
    "cdn1.crispadvertising.com",
    "cdn2.crispadvertising.com",
    "medrx.sensis.com.au",
    "rs-staticart.ybcdn.net",
    "img.ads.taptapnetworks.com",
    "adserver.ubiyoo.com",
    "c753738.r38.cf2.rackcdn.com",
    "edge.reporo.net",
    "ads.n-ws.org",
    "adultmoda.com",
    "ads.smartdevicemedia.com",
    "b.scorecardresearch.com",
    "m.adsymptotic.com",
    "cdn.vdopia.com",
    "api.yp.com",
    "asotrack1.fluentmobile.com",
    "android-sdk31.transpera.com",
    "apps.mobilityware.com",
    "ads.mobilityware.com",
    "ads.admarvel.com",
    "netdna.reporo.net",
    "www.eltrafiko.com",
    "cdn.trafficforce.com",
    "gts-ads.twistbox.com",
    "static.cdn.gtsmobi.com",
    "ads.matomymobile.com",
    "ads.adiquity.com",
    "img.ads.mobilefuse.net",
    "as.adfonic.net",
    "media.mobpartner.mobi",
    "cdn.us.goldspotmedia.com",
    "ads2.mediaarmor.com",
    "cdn.nearbyad.com",
    "ads.ookla.com",
    "mobiledl.adobe.com",
    "ads.flurry.com",
    "gemini.yahoo.com",
    "d3anogn3pbtk4v.cloudfront.net",
    "d3oltyb66oj2v8.cloudfront.net",
    "d2bgg7rjywcwsy.cloudfront.net",
    "a.vserv.mobi",
    "admin.vserv.mobi",
    "c.vserv.mobi",
    "ads.vserv.mobi",
    "sf.vserv.mobi",
    "hybl9bazbc35.pflexads.com",
    "hhbekxxw5d9e.pflexads.com",
    "www.pflexads.com",
    "orencia.pflexads.com",
    "atti.velti.com",
    "ru.velti.com",
    "mwc.velti.com",
    "cdn.celtra.com",
    "ads.celtra.com",
    "cache-ssl.celtra.com",
    "cache.celtra.com",
    "track.celtra.com",
    "wv.inner-active.mobi",
    "cdn1.inner-active.mobi",
    "m2m1.inner-active.mobi",
    "bos-tapreq01.jumptap.com",
    "bos-tapreq02.jumptap.com",
    "bos-tapreq03.jumptap.com",
    "bos-tapreq04.jumptap.com",
    "bos-tapreq05.jumptap.com",
    "bos-tapreq06.jumptap.com",
    "bos-tapreq07.jumptap.com",
    "bos-tapreq08.jumptap.com",
    "bos-tapreq09.jumptap.com",
    "bos-tapreq10.jumptap.com",
    "bos-tapreq11.jumptap.com",
    "bos-tapreq12.jumptap.com",
    "bos-tapreq13.jumptap.com",
    "bos-tapreq14.jumptap.com",
    "bos-tapreq15.jumptap.com",
    "bos-tapreq16.jumptap.com",
    "bos-tapreq17.jumptap.com",
    "bos-tapreq18.jumptap.com",
    "bos-tapreq19.jumptap.com",
    "bos-tapreq20.jumptap.com",
    "web64.jumptap.com",
    "web63.jumptap.com",
    "web65.jumptap.com",
    "bo.jumptap.com",
    "i.jumptap.com",
    "a.applovin.com",
    "d.applovin.com",
    "pdn.applovin.com",
    "mobpartner.mobi",
    "go.mobpartner.mobi",
    "r.mobpartner.mobi",
    "uk-ad2.adinfuse.com",
    "adinfuse.com",
    "go.adinfuse.com",
    "ad1.adinfuse.com",
    "ad2.adinfuse.com",
    "sky.adinfuse.com",
    "orange-fr.adinfuse.com",
    "sky-connect.adinfuse.com",
    "uk-go.adinfuse.com",
    "orangeuk-mc.adinfuse.com",
    "intouch.adinfuse.com",
    "funnel0.adinfuse.com",
    "cvt.mydas.mobi",
    "lp.mydas.mobi",
    "golds.lp.mydas.mobi",
    "suo.lp.mydas.mobi",
    "aio.lp.mydas.mobi",
    "lp.mp.mydas.mobi",
    "media.mydas.mobi",
    "ads.mp.mydas.mobi",
    "neptune.appads.com",
    "neptune1.appads.com",
    "neptune2.appads.com",
    "neptune3.appads.com",
    "saturn.appads.com",
    "saturn1.appads.com",
    "saturn2.appads.com",
    "saturn3.appads.com",
    "jupiter.appads.com",
    "jupiter1.appads.com",
    "jupiter2.appads.com",
    "jupiter3.appads.com",
    "req.appads.com",
    "req1.appads.com",
    "req2.appads.com",
    "req3.appads.com",
    "mc.yandex.ru",
    "an.yandex.ru",
    "swappit.tapad.com",
    "campaign-tapad.s3.amazonaws.com",
    "adsrv1.tapad.com",
    "ads1.mojiva.com",
    "ads2.mojiva.com",
    "ads3.mojiva.com",
    "ads4.mojiva.com",
    "ads5.mojiva.com",
    "i.w.inmobi.com",
    "r.w.inmobi.com",
    "c.w.inmobi.com",
    "adtracker.inmobi.com",
    "china.inmobi.com",
    "japan.inmobi.com",
    "mdn1.phluantmobile.net",
    "mdn2.phluantmobile.net",
    "mdn3.phluantmobile.net",
    "mdn3origin.phluantmobile.net",
    "soma.smaato.net",
    "c29new.smaato.net",
    "c01.smaato.net",
    "c02.smaato.net",
    "c03.smaato.net",
    "c04.smaato.net",
    "c05.smaato.net",
    "c06.smaato.net",
    "c07.smaato.net",
    "c08.smaato.net",
    "c09.smaato.net",
    "c10.smaato.net",
    "c11.smaato.net",
    "c12.smaato.net",
    "c13.smaato.net",
    "c14.smaato.net",
    "c15.smaato.net",
    "c16.smaato.net",
    "c17.smaato.net",
    "c18.smaato.net",
    "c19.smaato.net",
    "c20.smaato.net",
    "c21.smaato.net",
    "c22.smaato.net",
    "c23.smaato.net",
    "c24.smaato.net",
    "c25.smaato.net",
    "c26.smaato.net",
    "c27.smaato.net",
    "c28.smaato.net",
    "c29.smaato.net",
    "c30.smaato.net",
    "c31.smaato.net",
    "c32.smaato.net",
    "c33.smaato.net",
    "c34.smaato.net",
    "c35.smaato.net",
    "c36.smaato.net",
    "c37.smaato.net",
    "c38.smaato.net",
    "c39.smaato.net",
    "c40.smaato.net",
    "c41.smaato.net",
    "c42.smaato.net",
    "c43.smaato.net",
    "c44.smaato.net",
    "c45.smaato.net",
    "c46.smaato.net",
    "c47.smaato.net",
    "c48.smaato.net",
    "c49.smaato.net",
    "c50.smaato.net",
    "c51.smaato.net",
    "c52.smaato.net",
    "c53.smaato.net",
    "c54.smaato.net",
    "c55.smaato.net",
    "c56.smaato.net",
    "c57.smaato.net",
    "c58.smaato.net",
    "c59.smaato.net",
    "c60.smaato.net",
    "f03.smaato.net",
    "f04.smaato.net",
    "f05.smaato.net",
    "f06.smaato.net",
    "f07.smaato.net",
    "f08.smaato.net",
    "f09.smaato.net",
    "f10.smaato.net",
    "f11.smaato.net",
    "f12.smaato.net",
    "f13.smaato.net",
    "f14.smaato.net",
    "f15.smaato.net",
    "f16.smaato.net",
    "f17.smaato.net",
    "f18.smaato.net",
    "f19.smaato.net",
    "f20.smaato.net",
    "f21.smaato.net",
    "f22.smaato.net",
    "f23.smaato.net",
    "f24.smaato.net",
    "f25.smaato.net",
    "f26.smaato.net",
    "f27.smaato.net",
    "f28.smaato.net",
    "f29.smaato.net",
    "f30.smaato.net",
    "f31.smaato.net",
    "f32.smaato.net",
    "f33.smaato.net",
    "f34.smaato.net",
    "f35.smaato.net",
    "f36.smaato.net",
    "f37.smaato.net",
    "f38.smaato.net",
    "f39.smaato.net",
    "f40.smaato.net",
    "f41.smaato.net",
    "f42.smaato.net",
    "f43.smaato.net",
    "f44.smaato.net",
    "f45.smaato.net",
    "f46.smaato.net",
    "f47.smaato.net",
    "f48.smaato.net",
    "f49.smaato.net",
    "f50.smaato.net",
    "f51.smaato.net",
    "f52.smaato.net",
    "f53.smaato.net",
    "f54.smaato.net",
    "f55.smaato.net",
    "f56.smaato.net",
    "f57.smaato.net",
    "f58.smaato.net",
    "f59.smaato.net",
    "f60.smaato.net",
    "img.ads1.mojiva.com",
    "img.ads2.mojiva.com",
    "img.ads3.mojiva.com",
    "img.ads4.mojiva.com",
    "img.ads1.mocean.mobi",
    "img.ads2.mocean.mobi",
    "img.ads3.mocean.mobi",
    "img.ads4.mocean.mobi",
    "akamai.smartadserver.com",
    "cdn1.smartadserver.com",
    "diff.smartadserver.com",
    "diff2.smartadserver.com",
    "diff3.smartadserver.com",
    "eqx.smartadserver.com",
    "im2.smartadserver.com",
    "itx5-publicidad.smartadserver.com",
    "itx5.smartadserver.com",
    "tcy.smartadserver.com",
    "ww129.smartadserver.com",
    "ww13.smartadserver.com",
    "ww14.smartadserver.com",
    "ww234.smartadserver.com",
    "ww251.smartadserver.com",
    "ww264.smartadserver.com",
    "ww302.smartadserver.com",
    "ww362.smartadserver.com",
    "ww370.smartadserver.com",
    "ww381.smartadserver.com",
    "ww392.smartadserver.com",
    "ww55.smartadserver.com",
    "ww57.smartadserver.com",
    "ww84.smartadserver.com",
    "www.smartadserver.com",
    "www2.smartadserver.com",
    "www3.smartadserver.com",
    "www4.smartadserver.com",
    "ads.mobclix.com",
    "data.mobclix.com",
    "s.mobclix.com",
    "ads.mdotm.com",
    "cdn.mdotm.com",
    "ads2.greystripe.com",
    "adsx.greystripe.com",
    "c.greystripe.com",
    "aax-us-east.amazon-adsystem.com",
    "aax-us-west.amazon-adsystem.com",
    "s.amazon-adsystem.com",
    "admarvel.s3.amazonaws.com",
    "html5adkit.plusmo.s3.amazonaws.com",
    "inneractive-assets.s3.amazonaws.com",
    "strikeadcdn.s3.amazonaws.com",
    "a.admob.com",
    "analytics.admob.com",
    "c.admob.com",
    "media.admob.com",
    "p.admob.com",
    "met.adwhirl.com",
    "mob.adwhirl.com",
    "ad-g.doubleclick.net",
    "ad.doubleclick.net",
    "ad.mo.doubleclick.net",
    "doubleclick.net",
    "googleads.g.doubleclick.net",
    "pagead.googlesyndication.com",
    "pagead1.googlesyndication.com",
    "pagead2.googlesyndication.com",
    "events.foreseeresults.com",
    "survey.foreseeresults.com",
    "m.quantserve.com",
    "ad.leadboltmobile.net",
    "mobileads.msn.com",
    "img.adecorp.co.kr",
    "us0.adlibr.com",
    "ad.parrot.mable-inc.com",
    "aos.wall.youmi.net",
    "au.youmi.net",
    "coconuts.boy.jp",
    "iacpromotion.s3.amazonaws.com",
    "plugin.2easydroid.com",
    "adimg3.search.naver.net",
    "st.a-link.co.kr",
    "cdn.ajillionmax.com",
    "dispatch.admixer.co.kr",
    "ifc.inmobi.com",
    "thinknear-hosted.thinknearhub.com",
    "ads.adadapted.com",
    "analytics.localytics.com",
    "a.medialytics.com",
    "c.medialytics.com",
    "cdn.creative.medialytics.com",
    "p.medialytics.com",
    "px.cdn.creative.medialytics.com",
    "t.medialytics.com",
    "google-analytics.com",
    "googlesyndication.com",
    "applift.com",
    "trackersimulator.org",
    "eviltracker.net",
    "do-not-tracker.org",
]



from gettext import gettext as _

data = [
    {"id": "AC_3", "code": "AC-3", "title": _("Access Enforcement")},
    {
        "id": "AC_3_11",
        "code": "AC-3(11)",
        "title": _("Restrict access to specific info type"),
    },
    {"id": "AC_4", "code": "AC-4", "title": _("Information Flow Enforcement")},
    {"id": "AC_5", "code": "AC-5", "title": _("Separation of Duties")},
    {"id": "AC_6", "code": "AC-6", "title": _("Least Privilege")},
    {"id": "AC_16", "code": "AC-16", "title": _("Security Attributes")},
    {
        "id": "AC_17",
        "code": "AC-17",
        "title": _("Remote Access | MONITORING AND CONTROL"),
    },
    {
        "id": "AC_17_2",
        "code": "AC-17(2)",
        "title": _("Protection of Confidentiality and Integrity Using Encryption"),
    },
    {"id": "AC_18_1", "code": "AC-18(1)", "title": _("Authentication and encryption")},
    {
        "id": "AC_19_5",
        "code": "AC-19(5)",
        "title": _("Full device/container based encryption"),
    },
    {
        "id": "AU_13",
        "code": "AU-13",
        "title": _("Monitoring for Information Disclosure"),
    },
    {"id": "CA_2", "code": "CA-2", "title": _("Control Assessments")},
    {"id": "CA_3", "code": "CA-3", "title": _("Information Exchange")},
    {"id": "CA_7", "code": "CA-7", "title": _("Continuous Monitoring")},
    {"id": "CA_8", "code": "CA-8", "title": _("Penetration Testing")},
    {"id": "CM_2", "code": "CM-2", "title": _("Baseline Configuration")},
    {"id": "CM_3", "code": "CM-3", "title": _("Configuration Management")},
    {"id": "CM_6", "code": "CM-6", "title": _("Configuration Settings")},
    {"id": "CM_7", "code": "CM-7", "title": _("Least Functionality")},
    {"id": "CM_8", "code": "CM-8", "title": _("System Component Inventory")},
    {
        "id": "IA_3",
        "code": "IA-3",
        "title": _("Device Identification and Authentication"),
    },
    {
        "id": "IA_5",
        "code": "IA-5",
        "title": _("Identification and Authentication (Cryptographic Protections)"),
    },
    {
        "id": "IA_9",
        "code": "IA-9",
        "title": _("Service Identification and Authentication"),
    },
    {"id": "IR_4", "code": "IR-4", "title": _("Incident Handling")},
    {
        "id": "MA_3",
        "code": "MA-3",
        "title": _("Maintenance Tools | Software Updates and Patches"),
    },
    {"id": "MA_3_6", "code": "MA-3(6)", "title": _("Software Updates And Patches")},
    {
        "id": "PE_3",
        "code": "PE-3",
        "title": _("Physical Access Control | Tamper Protection"),
    },
    {"id": "PE_6", "code": "PE-6", "title": _("Monitoring Physical Access")},
    {"id": "PM_5", "code": "PM-5", "title": _("System Inventory")},
    {"id": "PM_14", "code": "PM-14", "title": _("Testing, Training, and Monitoring")},
    {"id": "PS_6", "code": "PS-6", "title": _("Access Agreements")},
    {"id": "RA_2", "code": "RA-2", "title": _("Security Categorization")},
    {"id": "RA_3", "code": "RA-3", "title": _("Risk Assessment")},
    {"id": "RA_5", "code": "RA-5", "title": _("Vulnerability Monitoring and Scanning")},
    {"id": "RA_9", "code": "RA-9", "title": _("Criticality Analysis")},
    {"id": "SA_3", "code": "SA-3", "title": _("System Development Life Cycle")},
    {"id": "SA_11", "code": "SA-11", "title": _("Developer Testing and Evaluation")},
    {"id": "SA_11_1", "code": "SA-11(1)", "title": _("STATIC CODE ANALYSIS")},
    {"id": "SA_11_4", "code": "SA-11(4)", "title": _("MANUAL CODE REVIEWS ")},
    {"id": "SA_11_5", "code": "SA-11(5)", "title": _("PENETRATION TESTING")},
    {"id": "SA_11_8", "code": "SA-11(8)", "title": _("DYNAMIC CODE ANALYSIS")},
    {
        "id": "SA_15",
        "code": "SA-15",
        "title": _("Development process, standards and tools"),
    },
    {"id": "SA_18", "code": "SA-18", "title": _("Tamper Resistance And Detection")},
    {"id": "SI_2", "code": "SI-2", "title": _("Flaw Remediation")},
    {"id": "SI_3", "code": "SI-3", "title": _("Malicious Code Protection")},
    {"id": "SI_4", "code": "SI-4", "title": _("System Monitoring")},
    {"id": "SI_4_22", "code": "SI-4(22)", "title": _("UNAUTHORIZED NETWORK SERVICES")},
    {
        "id": "SI_7",
        "code": "SI-7",
        "title": _("Software, Firmware, And Information Integrity"),
    },
    {"id": "SI_7_6", "code": "SI-7(6)", "title": _("Cryptographic Protection")},
    {"id": "SI_10", "code": "SI-10", "title": _("Information Input Validation")},
    {
        "id": "SI_10_5",
        "code": "SI-10(5)",
        "title": _("RESTRICT INPUTS TO TRUSTED SOURCES AND APPROVED FORMATS"),
    },
    {"id": "SI_10_6", "code": "SI-10(6)", "title": _("INJECTION PREVENTION")},
    {"id": "SI_16", "code": "SI-16", "title": _("Memory Protection")},
    {"id": "SC_7", "code": "SC-7", "title": _("Boundary Protection")},
    {
        "id": "SC_8",
        "code": "SC-8",
        "title": _("Transmission Confidentiality and Integrity"),
    },
    {
        "id": "SC_12",
        "code": "SC-12",
        "title": _("Cryptographic Key Establishment and Management"),
    },
    {"id": "SC_13", "code": "SC-13", "title": _("Cryptographic Protection")},
    {
        "id": "SC_17",
        "code": "SC-17",
        "title": _("Public Key Infrastructure Certificates"),
    },
    {"id": "SC_18", "code": "SC-18", "title": _("Mobile Code")},
    {"id": "SC_28", "code": "SC-28", "title": _("Protection of Information at Rest")},
    {"id": "SC_31", "code": "SC-31", "title": _("Use of Cryptography")},
    {"id": "SR_9", "code": "SR-9", "title": _("Tamper Resistance and Detection")},
]


class NISTSP80053:
    def __init__(self, id, code, title):
        self.pk = id
        self.id = id
        self.title = title
        self.code = code

    def __str__(self):
        return f"{self.id} - {self.code} - {self.title}"

    def __repr__(self):
        return "<NISTSP80053: %s>" % self.__str__()


NISTSP80053_DATA = {d["id"]: NISTSP80053(**d) for d in data}



from gettext import gettext as _

data = [
    {
        "title": _(
            "Install and maintain a firewall and router configuration to protect"
            "cardholder data"
        ),
        "code": "1.1",
        "id": "1_1",
        "description": _(
            "Establish firewall and router configuration standards that formalize "
            "testing whenever configurations change; that identify all "
            "connections to cardholder data (including wireless); that use "
            "various technical settings for each implementation; and stipulate "
            "a review of configuration rule sets at least every six months."
        ),
    },
    {
        "title": _(
            "Install and maintain a firewall and router configuration to protect "
            "cardholder data"
        ),
        "code": "1.2",
        "id": "1_2",
        "description": _(
            "Build firewall and router configurations that restrict "
            "all traffic from untrusted networks and hosts, except for protocols "
            "necessary for the cardholder data environment."
        ),
    },
    {
        "title": _(
            "Install and maintain a firewall and router configuration to protect "
            "cardholder data"
        ),
        "code": "1.3",
        "id": "1_3",
        "description": _(
            "Prohibit direct public access between the Internet and any system "
            "component in the cardholder data environment."
        ),
    },
    {
        "title": _(
            "Install and maintain a firewall and router configuration to protect "
            "cardholder data"
        ),
        "code": "1.4",
        "id": "1_4",
        "description": _(
            "Install personal firewall software on any mobile and/or "
            "employee-owned computers with direct connectivity to the Internet "
            "that are used to access the organization's network"
        ),
    },
    {
        "title": _(
            "Do not use vendor-supplied defaults for system passwords and other "
            "security parameters"
        ),
        "code": "2.1",
        "id": "2_1",
        "description": _(
            "Always change vendor-supplied defaults before installing a system "
            "on the network. This includes wireless devices that are connected "
            "to the cardholder data environment or are used to transmit "
            "cardholder data"
        ),
    },
    {
        "title": _(
            "Do not use vendor-supplied defaults for system passwords and other "
            "security parameters"
        ),
        "code": "2.2",
        "id": "2_2",
        "description": _(
            "Develop configuration standards for all system components that "
            "address all known security vulnerabilities and are consistent with "
            "industry-accepted definitions. Update system configuration standards "
            "as new vulnerability issues are identified."
        ),
    },
    {
        "title": _(
            "Do not use vendor-supplied defaults for system passwords and other "
            "security parameters"
        ),
        "code": "2.3",
        "id": "2_3",
        "description": _(
            "Encrypt using strong cryptography all non-console administrative "
            "access such as browser/web- based management tools"
        ),
    },
    {
        "title": _(
            "Do not use vendor-supplied defaults for system passwords and other "
            "security parameters"
        ),
        "code": "2.4",
        "id": "2_4",
        "description": _(
            "Shared hosting providers must protect each entity's hosted "
            "environment and cardholder data (details are in PCI DSS Appendix A: "
            "Additional PCI DSS Requirements for Shared Hosting Providers.)"
        ),
    },
    {
        "title": _("Protect stored cardholder data"),
        "code": "3.1",
        "id": "3_1",
        "description": _(
            "Limit cardholder data storage and retention time to that required "
            "for business, legal, and/or regulatory purposes, as documented in "
            "your data retention policy. Purge unnecessary stored data at least "
            "quarterly."
        ),
    },
    {
        "title": _("Protect stored cardholder data"),
        "code": "3.2",
        "id": "3_2",
        "description": _(
            "Do not store sensitive authentication data after authorization"
            " (even if it is encrypted). See guidelines in table below. Issuers "
            "and related entities may store sensitive authentication data if "
            "there is a business justification, and the data is stored securely."
        ),
    },
    {
        "title": _("Protect stored cardholder data"),
        "code": "3.3",
        "id": "3_3",
        "description": _(
            "Mask PAN when displayed; the first six and last four digits are the "
            "maximum number of digits you may display. Not applicable for "
            "authorized people with a legitimate business need to see the full "
            "PAN. Does not supersede stricter requirements in place for displays "
            "of cardholder data such as on a point-of-sale receipt."
        ),
    },
    {
        "title": _("Protect stored cardholder data"),
        "code": "3.4",
        "id": "3_4",
        "description": _(
            "Render PAN unreadable anywhere it is stored including on portable "
            "digital media, backup media, in logs, and data received from or "
            "stored by wireless networks. Technology solutions for this "
            "requirement may include strong one-way hash functions of the "
            "entire PAN, truncation, index tokens with securely stored pads, "
            "or strong cryptography. (See PCI DSS Glossary for definition of "
            "strong cryptography.)"
        ),
    },
    {
        "title": _("Protect stored cardholder data"),
        "code": "3.5",
        "id": "3_5",
        "description": _(
            "Protect any keys used for encryption of cardholder data from "
            "disclosure and misuse"
        ),
    },
    {
        "title": _("Protect stored cardholder data"),
        "code": "3.6",
        "id": "3_6",
        "description": _(
            "Fully document and implement all appropriate key management "
            "processes and procedures for cryptographic keys used for encryption "
            "of cardholder data"
        ),
    },
    {
        "title": _(
            "Encrypt transmission of cardholder data across open, public networks"
        ),
        "code": "4.1",
        "id": "4_1",
        "description": _(
            "Use strong cryptography and security protocols such as SSL/TLS, SSH "
            "or IPSec to safeguard sensitive cardholder data during transmission "
            "over open, public networks (e.g. Internet, wireless technologies, "
            "Global System for Mobile communications [GSM], General Packet Radio "
            "Service [GPRS]). Ensure wireless networks transmitting cardholder "
            "data or connected to the cardholder data environment use industry "
            "best practices (e.g., IEEE 802.11i) to implement strong encryption "
            "for authentication and transmission. The use of WEP as a security "
            "control is prohibited"
        ),
    },
    {
        "title": _(
            "Encrypt transmission of cardholder data across open, public networks"
        ),
        "code": "4.2",
        "id": "4_2",
        "description": _(
            "Never send unprotected PANs by end user messaging technologies"
        ),
    },
    {
        "title": _("Use and regularly update anti-virus software or programs"),
        "code": "5.1",
        "id": "5_1",
        "description": _(
            "Deploy anti-virus software on all systems affected by malicious "
            "software (particularly personal computers and servers)"
        ),
    },
    {
        "title": _("Use and regularly update anti-virus software or programs"),
        "code": "5.2",
        "id": "5_2",
        "description": _(
            "Ensure that all anti-virus mechanisms are current, actively running, "
            "and generating audit logs"
        ),
    },
    {
        "title": _("Develop and maintain secure systems and applications"),
        "code": "6.1",
        "id": "6_1",
        "description": _(
            "Ensure that all system components and software are protected from "
            "known vulnerabilities by having the latest vendor-supplied security "
            "patches installed. Deploy critical patches within a month of release"
        ),
    },
    {
        "title": _("Develop and maintain secure systems and applications"),
        "code": "6.2",
        "id": "6_2",
        "description": _(
            "Establish a process to identify and assign a risk ranking to newly "
            "discovered security vulnerabilities. Risk rankings should be based "
            "on industry best practices and guidelines."
        ),
    },
    {
        "title": _("Develop and maintain secure systems and applications"),
        "code": "6.3",
        "id": "6_3",
        "description": _(
            "Develop software applications (internal and external, and including "
            "web-based administrative access) in accordance with PCI DSS and "
            "based on industry best practices. Incorporate information security "
            "throughout the software development life cycle."
        ),
    },
    {
        "title": _("Develop and maintain secure systems and applications"),
        "code": "6.4",
        "id": "6_4",
        "description": _(
            "Follow change control processes and procedures for all changes to "
            "system components"
        ),
    },
    {
        "title": _("Develop and maintain secure systems and applications"),
        "code": "6.5",
        "id": "6_5",
        "description": _(
            "Develop applications based on secure coding guidelines and review "
            "custom application code to identify coding vulnerabilities. "
            "Follow up-to-date industry best practices to identify and manage "
            "vulnerabilities."
        ),
    },
    {
        "title": _("Develop and maintain secure systems and applications"),
        "code": "6.6",
        "id": "6_6",
        "description": _(
            "Ensure all public-facing web applications are protected against "
            "known attacks, either by performing code vulnerability reviews at "
            "least annually or by installing a web application firewall in front "
            "of public-facing web applications"
        ),
    },
    {
        "title": _("Restrict access to cardholder data by business need to know"),
        "code": "7.1",
        "id": "7_1",
        "description": _(
            "Limit access to system components and cardholder data to only those "
            "individuals whose job requires such access."
        ),
    },
    {
        "title": _("Restrict access to cardholder data by business need to know"),
        "code": "7.2",
        "id": "7_2",
        "description": _(
            "Establish an access control system for systems components with "
            "multiple users that restricts access based on a user's need to know, "
            "and is set to deny all unless specifically allowed"
        ),
    },
    {
        "title": _("Assign a unique ID to each person with computer access"),
        "code": "8.1",
        "id": "8_1",
        "description": _(
            "Assign all users a unique user name before allowing them to access "
            "system components or cardholder data."
        ),
    },
    {
        "title": _("Assign a unique ID to each person with computer access"),
        "code": "8.2",
        "id": "8_2",
        "description": _(
            "Employ at least one of these to authenticate all users: something "
            "you know, such as a password or passphrase; something you have, "
            "such as a token device or smart card; or something you are, "
            "such as a biometric"
        ),
    },
    {
        "title": _("Assign a unique ID to each person with computer access"),
        "code": "8.3",
        "id": "8_3",
        "description": _(
            "Implement two-factor authentication for remote access to the network "
            "by employees, administrators, and third parties. For example, use "
            "technologies such as remote authentication and dialin service "
            "(RADIUS) with tokens; terminal access controller access control "
            "system (TACACS) with tokens; or other technologies that facilitate "
            "two-factor authentication. Using one factor twice (e.g. using two "
            "separate passwords) is not considered two-factor authentication"
        ),
    },
    {
        "title": _("Assign a unique ID to each person with computer access"),
        "code": "8.4",
        "id": "8_4",
        "description": _(
            "Render all passwords unreadable during storage and transmission, "
            "for all system components, by using strong cryptography."
        ),
    },
    {
        "title": _("Assign a unique ID to each person with computer access"),
        "code": "8.5",
        "id": "8_5",
        "description": _(
            "Ensure proper user identification and authentication management for "
            "non-consumer users and administrators on all system components"
        ),
    },
    {
        "title": _("Assign a unique ID to each person with computer access"),
        "code": "8.6",
        "id": "8_6",
        "description": _(
            "Use of other authentication mechanisms such as physical security tokens, "
            "smart cards, and certificates must be assigned to an individual account."
        ),
    },
    {
        "title": _("Assign a unique ID to each person with computer access"),
        "code": "8.7",
        "id": "8_7",
        "description": _(
            "All access to any database containing cardholder data must be restricted: "
            "all user access must be through programmatic methods; only database "
            "administrators can have direct or query access; and application IDs for "
            "database applications can only be used by the applications (and not by "
            "users or non-application processes)."
        ),
    },
    {
        "title": _("Assign a unique ID to each person with computer access"),
        "code": "8.8",
        "id": "8_8",
        "description": _(
            "Ensure that related security policies and operational procedures are "
            "documented, in use, and known to all affected parties."
        ),
    },
    {
        "title": _("Restrict physical access to cardholder data"),
        "code": "9.1",
        "id": "9_1",
        "description": _(
            "Use appropriate facility entry controls to limit and monitor "
            "physical access to systems in the cardholder data environment"
        ),
    },
    {
        "title": _("Restrict physical access to cardholder data"),
        "code": "9.2",
        "id": "9_2",
        "description": _(
            "Develop procedures to easily distinguish between onsite personnel "
            "and visitors, especially in areas where cardholder data is accessible"
        ),
    },
    {
        "title": _("Restrict physical access to cardholder data"),
        "code": "9.3",
        "id": "9_3",
        "description": _(
            "Ensure all visitors are authorized before entering areas where "
            "cardholder data is processed or maintained; given a physical token "
            "that expires and that identifies visitors as not onsite personnel; "
            "and are asked to surrender the physical token before leaving the "
            "facility or at the date of expiration."
        ),
    },
    {
        "title": _("Restrict physical access to cardholder data"),
        "code": "9.4",
        "id": "9_4",
        "description": _(
            "Use a visitor log to maintain a physical audit trail of visitor "
            "information and activity, including visitor name and company, and "
            "the onsite personnel authorizing physical access. Retain the log "
            "for at least three months unless otherwise restricted by law."
        ),
    },
    {
        "title": _("Restrict physical access to cardholder data"),
        "code": "9.5",
        "id": "9_5",
        "description": _(
            "Store media back-ups in a secure location, preferably off site."
        ),
    },
    {
        "title": _("Restrict physical access to cardholder data"),
        "code": "9.6",
        "id": "9_6",
        "description": _("Physically secure all media."),
    },
    {
        "title": _("Restrict physical access to cardholder data"),
        "code": "9.7",
        "id": "9_7",
        "description": _(
            "Maintain strict control over the internal or external distribution "
            "of any kind of media. Classify media so the sensitivity of the data "
            "can be determined."
        ),
    },
    {
        "title": _("Restrict physical access to cardholder data"),
        "code": "9.8",
        "id": "9_8",
        "description": _(
            "Ensure that management approves any and all media moved from a "
            "secured area, especially when media is distributed to individuals"
        ),
    },
    {
        "title": _("Restrict physical access to cardholder data"),
        "code": "9.9",
        "id": "9_9",
        "description": _(
            "Maintain strict control over the storage and accessibility of media"
        ),
    },
    {
        "title": _("Restrict physical access to cardholder data"),
        "code": "9.10",
        "id": "9_10",
        "description": _(
            "Destroy media when it is no longer needed for business or legal " "reasons"
        ),
    },
    {
        "title": _(
            "Track and monitor all access to network resources and cardholder  " "data"
        ),
        "code": "10.1",
        "id": "10_1",
        "description": _(
            "Establish a process for linking all access to system components "
            "to each individual user especially access done with administrative "
            "privileges."
        ),
    },
    {
        "title": _(
            "Track and monitor all access to network resources and cardholder  " "data"
        ),
        "code": "10.2",
        "id": "10_2",
        "description": _(
            "Implement automated audit trails for all system components for "
            "reconstructing these events: all individual user accesses to "
            "cardholder data; all actions taken by any individual with root or "
            "administrative privileges; access to all audit trails; invalid "
            "logical access attempts; use of identification and authentication "
            "mechanisms; initialization of the audit logs; creation and "
            "deletion of system-level objects"
        ),
    },
    {
        "title": _(
            "Track and monitor all access to network resources and cardholder  " "data"
        ),
        "code": "10.3",
        "id": "10_3",
        "description": _(
            "Record audit trail entries for all system components for each event, "
            "including at a minimum: user identification, type of event, date and "
            "time, success or failure indication, origination of event, and "
            "identity or name of affected data, system component or resource. "
        ),
    },
    {
        "title": _(
            "Track and monitor all access to network resources and cardholder  " "data"
        ),
        "code": "10.4",
        "id": "10_4",
        "description": _(
            "Using time synchronization technology, synchronize all critical "
            "system clocks and times and implement controls for acquiring, "
            "distributing, and storing time."
        ),
    },
    {
        "title": _(
            "Track and monitor all access to network resources and cardholder  " "data"
        ),
        "code": "10.5",
        "id": "10_5",
        "description": _("Secure audit trails so they cannot be altered."),
    },
    {
        "title": _(
            "Track and monitor all access to network resources and cardholder  " "data"
        ),
        "code": "10.6",
        "id": "10_6",
        "description": _(
            "Review logs for all system components related to security functions "
            "at least daily"
        ),
    },
    {
        "title": _(
            "Track and monitor all access to network resources and cardholder  " "data"
        ),
        "code": "10.7",
        "id": "10_7",
        "description": _(
            "Retain audit trail history for at least one year; at least three "
            "months of history must be immediately available for analysis"
        ),
    },
    {
        "title": _("Regularly test security systems and processes"),
        "code": "11.1",
        "id": "11_1",
        "description": _(
            "Test for the presence of wireless access points and detect "
            "unauthorized wireless access points on a quarterly basis. "
            "Typical methods are wireless network scans, physical/logical "
            "inspections of system components and infrastructure, network "
            "access control (NAC), or wireless IDS/IPS. "
        ),
    },
    {
        "title": _("Regularly test security systems and processes"),
        "code": "11.2",
        "id": "11_2",
        "description": _(
            "Run internal and external network vulnerability scans at least "
            "quarterly and after any significant change in the network. After "
            "passing a scan for initial PCI DSS compliance, an entity must, in "
            "subsequent years, pass four consecutive quarterly scans as a "
            "requirement for compliance. Quarterly external scans must be "
            "performed by an Approved Scanning Vendor (ASV). Scans conducted "
            "after network changes may be performed by internal staff"
        ),
    },
    {
        "title": _("Regularly test security systems and processes"),
        "code": "11.3",
        "id": "11_3",
        "description": _(
            "Perform external and internal penetration testing, including "
            "network- and application-layer penetration tests, at least "
            "annually and after any significant infrastructure or application "
            "upgrade or modification."
        ),
    },
    {
        "title": _("Regularly test security systems and processes"),
        "code": "11.4",
        "id": "11_4",
        "description": _(
            "Use network intrusion detection systems and/or intrusion prevention "
            "systems to monitor all traffic at the perimeter of the cardholder "
            "data environment as well as at critical points inside of the "
            "cardholder data environment, and alert personnel to suspected "
            "compromises. IDS/IPS engines, baselines, and signatures must be "
            "kept up to date"
        ),
    },
    {
        "title": _("Regularly test security systems and processes"),
        "code": "11.5",
        "id": "11_5",
        "description": _(
            "Deploy file integrity monitoring tools to alert personnel to "
            "unauthorized modification of critical system files, configuration "
            "files or content files. Configure the software to perform critical "
            "file comparisons at least weekly"
        ),
    },
    {
        "title": _(
            "Maintain a policy that addresses information security for all " "personnel"
        ),
        "code": "12.1",
        "id": "12_1",
        "description": _(
            "Establish, publish, maintain, and disseminate a security policy "
            "that addresses all PCI DSS requirements, includes an annual "
            "process for identifying vulnerabilities and formally assessing "
            "risks, and includes a review at least once a year and when the "
            "environment changes"
        ),
    },
    {
        "title": _(
            "Maintain a policy that addresses information security for all " "personnel"
        ),
        "code": "12.2",
        "id": "12_2",
        "description": _(
            "Develop daily operational security procedures that are consistent "
            "with requirements in PCI DSS"
        ),
    },
    {
        "title": _(
            "Maintain a policy that addresses information security for all " "personnel"
        ),
        "code": "12.3",
        "id": "12_3",
        "description": _(
            "Develop usage policies for critical technologies to define their "
            "proper use by all personnel. These include remote access, wireless, "
            "removable electronic media, laptops, tablets, handheld devices, "
            "email and Internet"
        ),
    },
    {
        "title": _(
            "Maintain a policy that addresses information security for all " "personnel"
        ),
        "code": "12.4",
        "id": "12_4",
        "description": _(
            "Ensure that the security policy and procedures clearly define "
            "information security responsibilities for all personnel."
        ),
    },
    {
        "title": _(
            "Maintain a policy that addresses information security for all " "personnel"
        ),
        "code": "12.5",
        "id": "12_5",
        "description": _(
            "Assign to an individual or team information security "
            "responsibilities defined by 12.5 subsections."
        ),
    },
    {
        "title": _(
            "Maintain a policy that addresses information security for all " "personnel"
        ),
        "code": "12.6",
        "id": "12_6",
        "description": _(
            "Implement a formal security awareness program to make all "
            "personnel aware of the importance of cardholder data security"
        ),
    },
    {
        "title": _(
            "Maintain a policy that addresses information security for all " "personnel"
        ),
        "code": "12.7",
        "id": "12_7",
        "description": _(
            "Screen potential personnel prior to hire to minimize the risk of "
            "attacks from internal sources. Example screening includes previous "
            "employment history, criminal record, credit history, and reference "
            "checks"
        ),
    },
    {
        "title": _(
            "Maintain a policy that addresses information security for all " "personnel"
        ),
        "code": "12.8",
        "id": "12_8",
        "description": _(
            "If cardholder data is shared with service providers, maintain "
            "policies and procedures to formally identify service provider "
            "responsibilities for securing cardholder data, and monitor service "
            "providers' PCI DSS compliance status at least annually"
        ),
    },
    {
        "title": _(
            "Maintain a policy that addresses information security for all " "personnel"
        ),
        "code": "12.9",
        "id": "12_9",
        "description": _(
            "Implement an incident response plan. Be prepared to respond "
            "immediately to a system breach."
        ),
    },
]


class PCIDSS:
    def __init__(self, id, code, title, description, active=True):
        self.pk = id
        self.id = id
        self.title = title
        self.code = code
        self.description = description
        self.active = active

    def __str__(self):
        return f"{self.id} - {self.code} - {self.title} - {self.description}"

    def __repr__(self):
        return "<PCIDSS: %s>" % self.__str__()


PCIDSS_DATA = {d["id"]: PCIDSS(**d) for d in data}
